@@ -3,16 +3,16 @@
 #' @description Build and send OSRM API queries to get travel time matrices 
 #' between points. This function interfaces the \emph{table} OSRM service. 
 #' @param loc a data frame containing 3 fields: points identifiers, longitudes 
-#' and latitudes (WGS84). It can also be a SpatialPointsDataFrame or a 
-#' SpatialPolygonsDataFrame, then row names are used as identifiers.
+#' and latitudes (WGS84). It can also be a SpatialPointsDataFrame, a 
+#' SpatialPolygonsDataFrame or an sf object. If so, row names are used as identifiers.
 #' If loc parameter is used, all pair-wise distances are computed.
 #' @param src a data frame containing origin points identifiers, longitudes 
-#' and latitudes (WGS84). It can also be a SpatialPointsDataFrame or a 
-#' SpatialPolygonsDataFrame, then row names are used as identifiers. 
+#' and latitudes (WGS84). It can also be a SpatialPointsDataFrame, a 
+#' SpatialPolygonsDataFrame or an sf object. If so, row names are used as identifiers. 
 #' If dst and src parameters are used, only pairs between scr/dst are computed.
 #' @param dst a data frame containing destination points identifiers, longitudes 
-#' and latitudes (WGS84). It can also be a SpatialPointsDataFrame or a 
-#' SpatialPolygonsDataFrame, then row names are used as identifiers. 
+#' and latitudes (WGS84). It can also be a SpatialPointsDataFrame a 
+#' SpatialPolygonsDataFrame or an sf object. If so, row names are used as identifiers. 
 #' @param measure a character indicating what measures are calculated. It can 
 #' be "duration" (in minutes), "distance" (meters), or both c('duration',
 #' 'distance'). The demo server only allows "duration". 
@@ -26,12 +26,13 @@
 #' the origin and destination points actually used to compute the travel 
 #' times (WGS84).
 #' @details If loc, src or dst are data frames we assume that the 3 first 
-#' columns of the data.frame are: identifiers, longitudes and latitudes. 
+#' columns of the data frame are: identifiers, longitudes and latitudes. 
 #' @note 
 #' If you want to get a large number of distances make sure to set the 
 #' "max-table-size" argument (Max. locations supported in table) of the OSRM 
 #' server accordingly.
 #' @seealso \link{osrmIsochrone}
+#' @importFrom sf st_as_sf
 #' @examples
 #' \dontrun{
 #' # Load data
@@ -49,13 +50,13 @@
 #' # First 5 rows and columns
 #' distA2$durations[1:5,1:5]
 #' 
-#' # Inputs are SpatialPointsDataFrames
-#' distA3 <- osrmTable(loc = apotheke.sp[1:10,])
+#' # Inputs are sf points
+#' distA3 <- osrmTable(loc = apotheke.sf[1:10,])
 #' # First 5 rows and columns
 #' distA3$durations[1:5,1:5]
 #' 
 #' # Travel time matrix with different sets of origins and destinations
-#' distA4 <- osrmTable(src = apotheke.sp[1:10,], dst = apotheke.sp[11:20,])
+#' distA4 <- osrmTable(src = apotheke.sf[1:10,], dst = apotheke.sf[11:20,])
 #' # First 5 rows and columns
 #' distA4$durations[1:5,1:5]
 #' }
@@ -63,38 +64,40 @@
 osrmTable <- function(loc, src = NULL, dst = NULL, exclude = NULL, 
                       gepaf = FALSE, measure="duration"){
   tryCatch({
+    # input mgmt
     if (is.null(src)){
-      # check if inpout is sp, transform and name columns
       if(testSp(loc)){
-        loc <- spToDf(x = loc)
-      }else{
-        names(loc) <- c("id", "lon", "lat")
+        loc <- st_as_sf(x = loc)
       }
-      # Format
+      if(testSf(loc)){
+        loc <- sfToDf(x = loc)
+      }
+      names(loc) <- c("id", "lon", "lat")
       src <- loc
       dst <- loc
       sep <- "?"
-      
-      # Build the query
       req <- tableLoc(loc = loc, gepaf = gepaf)
     }else{
-      # check if inpout is sp, transform and name columns
       if(testSp(src)){
-        src <- spToDf(x = src)
-      }else{
-        names(src) <- c("id", "lon", "lat")
+        src <- st_as_sf(x = src)
+      }
+      if(testSf(src)){
+        src <- sfToDf(x = src)
       }
-      # check if inpout is sp, transform and name columns
       if(testSp(dst)){
-        dst <- spToDf(x = dst)
-      }else{
-        names(dst) <- c("id", "lon", "lat")
+        dst <- st_as_sf(x = dst)
       }
+      if(testSf(dst)){
+        dst <- sfToDf(x = dst)
+      }
+      
+      names(src) <- c("id", "lon", "lat")
+      names(dst) <- c("id", "lon", "lat")
+      
       
       # Build the query
       loc <- rbind(src, dst)
       sep = "&"
-          
       req <- paste(tableLoc(loc = loc, gepaf = gepaf),
                    "?sources=", 
                    paste(0:(nrow(src)-1), collapse = ";"), 
@@ -118,21 +121,15 @@ osrmTable <- function(loc, src = NULL, dst = NULL, exclude = NULL,
       annotations <- ""
     }
     
-    
-    
     # final req
     req <- paste0(req,exclude_str,annotations)
     
     # print(req)
-    
-    
     req <- utils::URLencode(req)
-    
     osrmLimit(nSrc = nrow(src), nDst = nrow(dst), nreq = nchar(req))
     
     # Get the result
-    resRaw <- RCurl::getURL(req, 
-                            useragent = "'osrm' R package")
+    resRaw <- RCurl::getURL(req, useragent = "'osrm' R package")
     
     # Parse the results
     res <- jsonlite::fromJSON(resRaw)
@@ -152,7 +149,7 @@ osrmTable <- function(loc, src = NULL, dst = NULL, exclude = NULL,
       output$durations <- durTableFormat(res = res, src = src, dst = dst)
     }
     if(!is.null(res$distances)){
-    # get the distance table
+      # get the distance table
       output$distances <- distTableFormat(res = res, src = src, dst = dst)  
     }
     # get the coordinates
